==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da directiva de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da directiva de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "Disable-user-theming should be true or false" : "Disable-user-theming (desactivar o tema do usuario) debe ser verdadeiro ou falso",
    "Saved" : "Gardado",
    "Invalid app given" : "A aplicación non é válida",
    "Invalid type for setting \"defaultApp\" given" : "O tipo non é válido para o axuste «defaultApp».",
    "Invalid setting key" : "Chave de axuste incorrecta",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "Failed to clean up the old administration theming images folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes de temas",
    "Failed to clean up the old administration image folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes da aplicación de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Appearance and accessibility" : "Aparencia e accesibilidade",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP «imagick» non está activado aínda que a aplicación de temas si o estea. Para que a xeración de favicon funcione correctamente, é necesario instalar e activar este módulo.",
    "Dark theme with high contrast mode" : "Tema escuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semellante ao modo de alto contraste, mais con cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Activar o tema escuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema escuro para aliviar os seus ollos reducindo a luminosidade e o brillo xerais.",
    "System default theme" : "Tema predeterminado do sistema",
    "Enable the system default" : "Activar o predeterminado do sistema ",
    "Using the default system appearance." : "Usando a aparencia predeterminada do sistema.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "Enable dyslexia font" : "Activar o tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar o modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar o tema claro predeterminado",
    "The default light appearance." : "A aparencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Directiva de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Advanced options" : "Opcións avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalar a extensión PHP ImageMagick con compatibilidade con imaxes SVG para xerar automaticamente favicons baseados no logotipo e na cor enviados.",
    "Name" : "Nome",
    "Web link" : "Ligazón web",
    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
    "Slogan" : "Lema",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Background and login image" : "Imaxe de fondo e acceso",
    "Upload new background and login image" : "Enviar unha nova imaxe de fondo e de acceso",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á directiva de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "User settings" : "Axustes de usuario",
    "Disable user theming" : "Desactivar o tema do usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode activar esta opción.",
    "Background" : "Fondo",
    "Customization has been disabled by your administrator" : "O seu administrador desactivou a personalización",
    "Set a custom background" : "Estabelecer un fondo personalizado",
    "Keyboard shortcuts" : "Atallos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Disable all keyboard shortcuts" : "Desactivar todos os atallos de teclado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Para nós o acceso universal é moi importante. Seguimos os estándares web e comprobamos que todo poida ser utilizado sen rato e software de axuda como os lectores de pantalla. O noso obxectivo é ter cumprir ás {guidelines}Directrices de accesibilidade ao contido web{linkend}  2.1 a nivel AA, co tema de alto contraste incluso a nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se atopa algúnha incidencia, non dubide en informalo no {issuetracker}noso seguidor de incidencias{linkend} E se quere involucrarse, únase ao {designteam}noso equipo de deseño {linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicación seleccionada actual: {app}, posición {position} de {total}",
    "Move up" : "Mover cara arriba",
    "Move down" : "Mover cara abaixo",
    "Custom background" : "Fondo personalizado",
    "Default background" : "Fondo predeterminado",
    "Change color" : "Cambiar a cor",
    "No background" : "Sen fondo",
    "Select a background from your files" : "Seleccione un fondo dende os seus ficheiros",
    "Select background" : "Seleccione o fondo",
    "No background has been selected" : "Non foi seleccionado ningún fondo",
    "Theme selection is enforced" : "Imponse a selección de temas",
    "Navigation bar settings" : "Axustes da barra de navegación",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Pode configurar a orde das aplicacións utilizadas na barra de navegación. A primeira entrada será a aplicación predeterminada, abriráse tras de acceder ou ao premer no logotipo.",
    "The default app can not be changed because it was configured by the administrator." : "A aplicación predeterminada non se pode cambiar porque foi configurada pola administración.",
    "The app order was changed, to see it in action you have to reload the page." : "Cambiouse a orde das aplicacións, para vela en acción ten que cargar de novo a páxina.",
    "Reset default app order" : "Restablecer a orde predeterminada das aplicacións",
    "Could not set the app order" : "Non foi posíbel estabelecer a orde das aplicacións",
    "Could not reset the app order" : "Non foi posíbel restabelecer a orde das aplicacións",
    "Default app" : "Aplicación predeterminada",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "A aplicación predeterminada é a aplicación que se abre p. ex. após acceder ou cando se preme no logotipo do menú.",
    "Use custom default app" : "Usar a aplicación predeterminada personalizada",
    "Global default app" : "Aplicación predeterminada global",
    "Global default apps" : "Aplicacións predeterminadas globais",
    "Default app priority" : "Prioridade predeterminada da aplicación",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Se unha aplicación non está activada para un usuario, utilízase a seguinte aplicación con menor prioridade.",
    "Could not set global default apps" : "Non foi posíbel estabelecer as aplicacións predeterminadas globais",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Upload" : "Enviar",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Select a custom color" : "Seleccione unha cor personalizada"
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.2.tgz: share/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da directiva de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da directiva de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "Disable-user-theming should be true or false" : "Disable-user-theming (desactivar o tema do usuario) debe ser verdadeiro ou falso",
    "Saved" : "Gardado",
    "Invalid app given" : "A aplicación non é válida",
    "Invalid type for setting \"defaultApp\" given" : "O tipo non é válido para o axuste «defaultApp».",
    "Invalid setting key" : "Chave de axuste incorrecta",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes da aplicación de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Appearance and accessibility" : "Aparencia e accesibilidade",
    "PHP Imagick module" : "Módulo PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP «imagick» non está activado aínda que a aplicación de temas si o estea. Para que a xeración de favicon funcione correctamente, é necesario instalar e activar este módulo.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "O módulo PHP «imagick» nesta instancia non ten compatibilidade con SVG. Para unha mellor compatibilidade recoméndase instalalo.",
    "Dark theme with high contrast mode" : "Tema escuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semellante ao modo de alto contraste, mais con cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Activar o tema escuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema escuro para aliviar os seus ollos reducindo a luminosidade e o brillo xerais.",
    "System default theme" : "Tema predeterminado do sistema",
    "Enable the system default" : "Activar o predeterminado do sistema ",
    "Using the default system appearance." : "Usando a aparencia predeterminada do sistema.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "Enable dyslexia font" : "Activar o tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar o modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar o tema claro predeterminado",
    "The default light appearance." : "A aparencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Directiva de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "En troques dunha imaxe de fondo, tamén pode configurar unha cor de fondo liso. Se usa unha imaxe de fondo, o cambio da cor influirá na cor das iconas do menú da aplicación.",
    "Background color" : "Cor de fondo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Logo" : "Logotipo",
    "Upload new background and login image" : "Enviar unha nova imaxe de fondo e de acceso",
    "Background and login image" : "Imaxe de fondo e acceso",
    "Advanced options" : "Opcións avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalar a extensión PHP ImageMagick con compatibilidade con imaxes SVG para xerar automaticamente favicons baseados no logotipo e na cor enviados.",
    "Name" : "Nome",
    "Web link" : "Ligazón web",
    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
    "Slogan" : "Lema",
    "Primary color" : "Cor principal",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "A cor principal úsase para resaltar elementos como botóns importantes. Pode axustarse lixeiramente dependendo do esquema de cores actual.",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á directiva de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "User settings" : "Axustes de usuario",
    "Disable user theming" : "Desactivar o tema do usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode activar esta opción.",
    "Appearance and accessibility settings" : "Axustes de aparencia e accesibilidade",
    "Misc accessibility options" : "Varias opcións de accesibilidade",
    "Enable blur background filter (may increase GPU load)" : "Activar o filtro de fondo esvaído (pode aumentar a carga da GPU)",
    "Customization has been disabled by your administrator" : "O seu administrador desactivou a personalización",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Defina unha cor principal para resaltar elementos importantes. A cor utilizada para elementos como os botóns principais pode diferir un pouco a medida que se axusta para cumprir cos requisitos de accesibilidade.",
    "Background and color" : "Fondo e cor",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "O fondo pódese definir cunha imaxe predeterminada, unha imaxe personalizada ou unha cor lisa.",
    "Keyboard shortcuts" : "Atallos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Disable all keyboard shortcuts" : "Desactivar todos os atallos de teclado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Para nós o acceso universal é moi importante. Seguimos os estándares web e comprobamos que todo poida ser utilizado sen rato e software de axuda como os lectores de pantalla. O noso obxectivo é ter cumprir ás {guidelines}Directrices de accesibilidade ao contido web{linkend}  2.1 a nivel AA, co tema de alto contraste incluso a nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se atopa algúnha incidencia, non dubide en informalo no {issuetracker}noso seguidor de incidencias{linkend} E se quere involucrarse, únase ao {designteam}noso equipo de deseño {linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicación seleccionada actual: {app}, posición {position} de {total}",
    "Move up" : "Mover cara arriba",
    "Move down" : "Mover cara abaixo",
    "Custom background" : "Fondo personalizado",
    "Plain background" : "Fondo sinxelo",
    "Default background" : "Fondo predeterminado",
    "Select a background from your files" : "Seleccione un fondo dende os seus ficheiros",
    "Select background" : "Seleccione o fondo",
    "No background has been selected" : "Non foi seleccionado ningún fondo",
    "Theme selection is enforced" : "Imponse a selección de temas",
    "Navigation bar settings" : "Axustes da barra de navegación",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Pode configurar a orde das aplicacións utilizadas na barra de navegación. A primeira entrada será a aplicación predeterminada, abriráse tras de acceder ou ao premer no logotipo.",
    "The default app can not be changed because it was configured by the administrator." : "A aplicación predeterminada non se pode cambiar porque foi configurada pola administración.",
    "The app order was changed, to see it in action you have to reload the page." : "Cambiouse a orde das aplicacións, para vela en acción ten que cargar de novo a páxina.",
    "Reset default app order" : "Restablecer a orde predeterminada das aplicacións",
    "Could not set the app order" : "Non foi posíbel definir a orde das aplicacións",
    "Could not reset the app order" : "Non foi posíbel restabelecer a orde das aplicacións",
    "Reset primary color" : "Restabelecer a cor principal",
    "Could not set primary color" : "Non foi posíbel definir a cor principal",
    "Default app" : "Aplicación predeterminada",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "A aplicación predeterminada é a aplicación que se abre p. ex. após acceder ou cando se preme no logotipo do menú.",
    "Use custom default app" : "Usar a aplicación predeterminada personalizada",
    "Global default app" : "Aplicación predeterminada global",
    "Global default apps" : "Aplicacións predeterminadas globais",
    "Default app priority" : "Prioridade predeterminada da aplicación",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Se unha aplicación non está activada para un usuario, utilízase a seguinte aplicación con menor prioridade.",
    "Could not set global default apps" : "Non foi posíbel definir as aplicacións predeterminadas globais",
    "Select a custom color" : "Seleccione unha cor personalizada",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Upload" : "Enviar",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Color" : "Cor",
    "Background" : "Fondo",
    "Set a custom background" : "Definir un fondo personalizado",
    "Change color" : "Cambiar a cor",
    "No background" : "Sen fondo"
},
"nplurals=2; plural=(n != 1);");
